<?php
/*
 * PSX is an open source PHP framework to develop RESTful APIs.
 * For the current version and information visit <https://phpsx.org>
 *
 * Copyright 2010-2023 Christoph Kappestein <christoph.kappestein@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace PSX\Sql;

use Doctrine\DBAL\Connection;
use PSX\Sql\Exception\InvalidTableException;

/**
 * TableManager
 *
 * @author  Christoph Kappestein <christoph.kappestein@gmail.com>
 * @license http://www.apache.org/licenses/LICENSE-2.0
 * @link    https://phpsx.org
 */
class TableManager implements TableManagerInterface
{
    private Connection $connection;
    private array $container;

    public function __construct(Connection $connection)
    {
        $this->connection = $connection;
        $this->container = [];
    }

    public function getConnection(): Connection
    {
        return $this->connection;
    }

    public function getTable(string $tableClass): ViewInterface
    {
        if (isset($this->container[$tableClass])) {
            return $this->container[$tableClass];
        }

        if (!class_exists($tableClass)) {
            throw new InvalidTableException('Provided table ' . $tableClass . ' does not exist');
        }

        return $this->container[$tableClass] = new $tableClass($this);
    }
}
